( cd sbin ; rm -rf raidstop )
( cd sbin ; ln -sf raidstart raidstop )
( cd sbin ; rm -rf raidhotadd )
( cd sbin ; ln -sf raidstart raidhotadd )
( cd sbin ; rm -rf raidhotremove )
( cd sbin ; ln -sf raidstart raidhotremove )
( cd sbin ; rm -rf raidsetfaulty )
( cd sbin ; ln -sf raidstart raidsetfaulty )
( cd sbin ; rm -rf raid0run )
( cd sbin ; ln -sf mkraid raid0run )
( cd usr/share ; rm -rf man )
( cd usr/share ; ln -sf ../man man )
